@@ -5,19 +5,19 @@
 
 #dataSize <- function(object) {return(object@file@datasize)}
 dataSize <- function(object) {
-	if (class(object) != 'character'){
+	if (!inherits(object, 'character')) {
 		object <- dataType(object)
 	}
 	return( as.integer (substr(object, 4, 4)) )
 }
 
 dataSigned <- function(object) {
-	if (class(object) != 'character') { object <- dataType(object) }
+	if (!inherits(object, 'character')) { object <- dataType(object) }
 	ifelse(substr(object, 5, 5) == 'U', FALSE, TRUE )
 }
 
 .shortDataType <- function(object) {
-	if (class(object) != 'character') {
+	if (!inherits(object, 'character')){
 		object <- dataType(object)
 	}
 	return( substr(object, 1, 3)) 
@@ -46,23 +46,31 @@ fromDisk <- function(x) {
 	}
 }
 	
-inMemory <- function(x) {
-	if (inherits( x, 'RasterStack' )) {
-		return( all( sapply( x@layers, function(x) x@data@inmemory )))
-	} else {
-		return( x@data@inmemory )
-	}
-}
 
+setMethod("inMemory", signature(x="BasicRaster"), 
+	function(x) {
+		if (inherits( x, 'RasterStack' )) {
+			return( all( sapply( x@layers, function(x) x@data@inmemory )))
+		} else if (inherits(x, "Raster")) {
+			return( x@data@inmemory )
+		} else {
+			TRUE
+		}
+	}
+)
 
-hasValues <- function(x) {
-	if (class(x) == 'BasicRaster') { return(FALSE) }
-	if (inherits(x, 'RasterStack')) { 
-		if (nlayers(x) > 0) return(TRUE) else return(FALSE)
+setMethod("hasValues", signature(x="BasicRaster"), 
+	function(x) {
+		if (inherits(x, 'RasterStack')) { 
+			if (nlayers(x) > 0) return(TRUE) else return(FALSE)
+		} else if (inherits(x, "Raster")) {
+			if ( fromDisk(x)  | inMemory(x) ) {
+				return(TRUE)
+			} else {
+				return(FALSE)
+			}
+		} else {
+			FALSE
+		}
 	}
-	if ( fromDisk(x)  | inMemory(x) ) {
-		return(TRUE)
-	} else {
-		return(FALSE)
-	}
-}
+)
