@@ -3,17 +3,30 @@
 # Version 0.9
 # Licence GPL v3
 
+.ext2bb <- function(e) {
+	matrix(as.vector(e), ncol=2, byrow=TRUE)
+}
+
+#setMethod("bbox", signature(obj="SpatRaster"), 
+#	function(obj){ 
+#		.ext2bb(ext(obj))
+#	}
+#)
+
+#setMethod("bbox", signature(obj="SpatVector"), 
+#	function(obj){ 
+#		.ext2bb(ext(obj))
+#	}
+#)
+
 
 
-if (!isGeneric("extent")) {
-	setGeneric("extent", function(x, ...)
-		standardGeneric("extent"))
-}	
 
 setMethod('extent', signature(x='Extent'), 
 	function(x){ return(x) }
 )
 
+
 setMethod('extent', signature(x='BasicRaster'), 
 	function(x, r1, r2, c1, c2){ 
 		e <- x@extent
@@ -76,7 +89,7 @@ setMethod('extent', signature(x='BasicRaster'),
 
 setMethod('extent', signature(x='Spatial'), 
 	function(x){ 
-		bndbox <- bbox(x)
+		bndbox <- sp::bbox(x)
 		e <- methods::new('Extent')
 		e@xmin <- bndbox[1,1]
 		e@xmax <- bndbox[1,2]
@@ -86,6 +99,18 @@ setMethod('extent', signature(x='Spatial'),
 	}
 )
 
+
+setMethod('extent', signature(x='bbox'), 
+	function(x){ 
+		e <- methods::new('Extent')
+		e@xmin <- x[1]
+		e@xmax <- x[3]
+		e@ymin <- x[2]
+		e@ymax <- x[4]
+		return(e) 
+	}
+)
+
 setMethod('extent', signature(x='sf'), 
 	function(x){ 
 		if (!requireNamespace("sf")) {
@@ -211,3 +236,5 @@ setReplaceMethod("[", c("Extent","numeric","missing"),
 		return(x)
 	}
 )
+
+
